@@ -684,17 +684,20 @@ int fitspng(char *fitsname, char *png, int bit_depth,
      YYYY-MM-DDTHH:MM:SSS.SSS, however the rule is violated
      by many software writing obsolete YYYY-MM-DD keyword.
   */
-  for( i = 0, c = fval[3], c0 = fval[3]; *c != '\0'; c++) {
-    if( *c == '-' || *c == 'T' || *c == ':' || *c == ' ' || *(c+1) == '\0') {
-      n = c - c0;
-      if( *(c+1) == '\0' )
-	n++;
-      tm[i++] = strndup(c0,n);
-      c0 = c + 1;
+  i = 0;
+  if( fval[3] ) {
+    for( i = 0, c = fval[3], c0 = fval[3]; *c != '\0'; c++) {
+      if( *c == '-' || *c == 'T' || *c == ':' || *c == ' ' || *(c+1) == '\0') {
+	n = c - c0;
+	if( *(c+1) == '\0' )
+	  n++;
+	tm[i++] = strndup(c0,n);
+	c0 = c + 1;
+      }
     }
+    /* This loop is my own bugy implementation of bugy strtok
+       (https://sourceware.org/bugzilla/show_bug.cgi?id=16640) */
   }
-  /* This loop is my own bugy implementation of bugy strtok
-     (https://sourceware.org/bugzilla/show_bug.cgi?id=16640) */
   if( i == 6 ) {
     if( sscanf(tm[5],"%f",&r) == 1 )
       i = rint(r);
